@@ -13,6 +13,6 @@
 
 SCRIPT_DIR=$(cd $(dirname $0);pwd)
 
-DATA_SCRIPT="${SCRIPT_DIR}/scripts/cloud_data_maint_EN.sh DELETE"
+DATA_SCRIPT="${SCRIPT_DIR}/scripts/aws_option_uninstall_data.sql"
 
 . ${SCRIPT_DIR}/scripts/cloud_option_uninstall_main.sh
