@@ -113,7 +113,7 @@ CREATE TABLE cc_cloud_user (
     account_resource_id character varying(64) NOT NULL,
     cloud_user_name character varying(128) NOT NULL,
     description character varying(256) NOT NULL,
-    secret_key character varying(64) NOT NULL,
+    secret_key character varying(8192) NOT NULL,
     access_key character varying(64) NOT NULL,
     cloud_user_type character varying(64) NOT NULL,
     role_id character varying(64) NOT NULL,
@@ -347,7 +347,7 @@ CREATE TABLE cc_cloud_template (
 	account_resource_id character varying(64) NOT NULL,
 	template_name varchar(128),
 	cloud_user_id varchar(64) NOT NULL,
-	image_id varchar(64) NOT NULL,
+	image_id varchar(1024) NOT NULL,
 	jobunit_id varchar(64) NOT NULL,
 	launch_job_id varchar(64),
 	start_job_id varchar(64),
@@ -446,28 +446,6 @@ ALTER TABLE ONLY cc_cloud_auto_control
 
 COMMIT;
 
-/*
-BEGIN;
-
-CREATE TABLE cc_cloud_billing_detail (
-    account_resource_id character varying(64) NOT NULL,
-    target_date date NOT NULL,
-    facility_id character varying(64) NOT NULL,
-    facility_name character varying(128),
-    category character varying(64) NOT NULL,
-    category_detail character varying(128) NOT NULL,
-    display_name character varying(1024) NOT NULL,
-    assign_facility_id_list character varying(1024) NOT NULL,
-    cost numeric,
-    unit character varying(64)
-);
-
-ALTER TABLE ONLY cc_cloud_billing_detail
-    ADD CONSTRAINT cc_cloud_billing_detail_pkey PRIMARY KEY (account_resource_id, target_date, facility_id, category, category_detail, display_name,assign_facility_id_list);
-
-COMMIT;
-*/
-
 BEGIN;
 
 CREATE TABLE cc_cloud_billing_detail (
@@ -475,7 +453,7 @@ CREATE TABLE cc_cloud_billing_detail (
     account_resource_id character varying(64) NOT NULL,
     account_resource_name character varying(256) NOT NULL,
     target_date date NOT NULL,
-	resource_id varchar(64),
+	resource_id varchar(1024),
     category character varying(64) NOT NULL,
     category_detail character varying(128),
     display_name character varying(1024) NOT NULL,
@@ -505,3 +483,12 @@ ALTER TABLE ONLY cc_cloud_billing_detail_relation
     ADD CONSTRAINT f_key_cc_cloud_billing_detail_relation_billing_detail_id FOREIGN KEY (billing_detail_id) REFERENCES cc_cloud_billing_detail(billing_detail_id) ON DELETE CASCADE;
 
 COMMIT;
+
+
+BEGIN;
+
+--\set ON_ERROR_STOP
+
+INSERT INTO cc_system_privilege (role_id, system_function, system_privilege) SELECT 'HINEMOS_MODULE','CloudManagement','READ' FROM cc_system_privilege WHERE NOT EXISTS (SELECT * FROM cc_system_privilege WHERE role_id = 'HINEMOS_MODULE' AND system_function = 'CloudManagement' AND system_privilege = 'READ') limit 1;
+
+COMMIT;
\ No newline at end of file
