@@ -21,7 +21,7 @@ set_hinemos_home
 . ${SCRIPT_DIR}/scripts/conf.sh
 
 uninstall_libraries "${INSTALL_FILES}"
-deregist_persistence "${ENTITY_JARS}" {LIBDIR} ${PERSISTENCE_XML_PATH} "${ORM_XML_PATHS}"
+deregist_persistence "${ENTITY_JARS}" ${LIBDIR} ${PERSISTENCE_XML_PATH} "${ORM_XML_PATHS}"
 uninstall_settings ${SCRIPT_DIR} ${HINEMOS_HOME}
 
 if [ -n "${DATA_SCRIPT}" ]; then
