@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2013 NTT DATA Corporation
+Copyright (C) 2014 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
@@ -36,6 +36,7 @@ public enum ErrorCode {
 	ACCOUNTRESOURCE_MUST_HAVE_ACCOUNT("message.validation.accountresource.must_have_account"),
 	ACCOUNTRESOURCE_NOT_REMOVE_NOT_TO_REMOVE_FACILITY("message.account_resource.not_delete_account_resource_not_to_delete_facility.exception"),
 	ACCOUNTRESOURCE_NOT_REMOVE_NOT_TO_REMOVE_JOBUNIT("message.account_resource.not_delete_account_resource_not_to_delete_jobunit.exception"),
+	ACCOUNTRESOURCE_JOBUNIT_ALREADY_EXIST("message.validation.account_resource.jobunit_already_exist"),
 
 	CLOUDSERVICE_ALREADY_EXIST("message.validation.cloudservice.already_exist"),
 	CLOUDSERVICE_INVALID_CLOUDSERVICE_NOT_FOUND("message.validation.entity.invalid_pk.not_found"),
@@ -93,17 +94,12 @@ public enum ErrorCode {
 	OBJECTPRIVILEGE_NOT_FOUND_TARGET_OBJECT("message.validation.objectprivilege.not_found_target_object"),
 	OBJECTPRIVILEGE_UNAUTHORIZED_TO_TARGET_OBJECT("message.validation.objectprivilege.unauthorized_to_target_object"),
 	
-	
-/*
-	message.validation.cloud_user.message4=ログインユーザー「{0}」は、クラウドユーザーに紐付いていません。
-	message.validation.cloud_user.message5=親クラウドユーザは、ルートアカウントのみ指定可能です。
-	message.validation.cloud_user.message6=子クラウドユーザは、親クラウドユーザに指定されたルートアカウント配下の IAM ユーザーのみ指定可能です。
-	message.validation.cloud_user.message7=変更したアクセスキーおよびシークレットキーは、作成時のルートアカウントとは別のルートアカウントを表しています。
-	message.validation.cloud_user.message8=変更対象のクラウドユーザー「{0}」を確認できません。
-*/
-	
 	BILLINGALARM_INVALID_BILLINGALARMID_NOT_FOUND("BillingAlarm.InvalidBillingAlarmId.NotFound"),
 	EC2SERVICE_INVALID_REGIONID_NOT_FOUND("EC2Service.InvaidRegionId.NotFound"), 
+	
+	FACILITY_NOT_FOUND("message.validation.facility.not_found"),
+
+	NOT_SUPPORT_FUNCTION("message.validation.cloud_function.not_support_function"),
 	;
 	
 	private String[] messageIds;
