@@ -83,6 +83,7 @@ import com.clustercontrol.cloud.bean.StorageAttachmentStateKind;
 import com.clustercontrol.cloud.bean.StorageStateKind;
 import com.clustercontrol.cloud.bean.Tag;
 import com.clustercontrol.cloud.bean.Zone;
+import com.clustercontrol.cloud.commons.PropertyContract;
 import com.clustercontrol.cloud.persistence.TransactionException;
 import com.clustercontrol.cloud.persistence.Transactional;
 import com.fasterxml.jackson.databind.ObjectMapper;
@@ -144,7 +145,8 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 	private IRegion region;
 	private ICredential credential;
 	private IStore store;
-
+	private boolean fqdn = AWSOptionPropertyConstants.aws_hostname_fqdn.match(PropertyContract.on);
+	
 	@Override
 	public void setAccessDestination(ICredential credential, IRegion region) {
 		this.region = region;
@@ -253,12 +255,34 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 			instance.setPlatform(awsInstance.getPlatform() == null ? PlatformKind.linux: PlatformKind.windows);
 			instance.setState(instanceStateKind(awsInstance.getState().getName()));
 
+			String dnsName;
+			String hostName;
 			if (AWSOptionPropertyConstants.aws_node_ip.match(AWSOptionPropertyConstants.qublic)) {
-				instance.setHostName(awsInstance.getPublicDnsName());
+				dnsName = awsInstance.getPublicDnsName();
+				Logger.getLogger(this.getClass()).info("createInstance() public dns(fqdn) " + dnsName);
+				if(fqdn || dnsName == null || !dnsName.contains(".")){
+					instance.setHostName(dnsName);
+					Logger.getLogger(this.getClass()).info("createInstance() set public dns(fqdn) " + dnsName);
+				}
+				else{
+					hostName = dnsName.substring(0,dnsName.indexOf("."));
+					Logger.getLogger(this.getClass()).info("createInstance() set hostname " + hostName);
+					instance.setHostName(hostName);
+				}
 				instance.setIpAddress(awsInstance.getPublicIpAddress());
 			}
 			else {
-				instance.setHostName(awsInstance.getPrivateDnsName());
+				dnsName = awsInstance.getPrivateDnsName();
+				Logger.getLogger(this.getClass()).info("createInstance() private dns(fqdn) " + dnsName);
+				if(fqdn || dnsName == null || !dnsName.contains(".")){
+					instance.setHostName(dnsName);
+					Logger.getLogger(this.getClass()).info("createInstance() set private dns(fqdn) " + dnsName);
+				}
+				else{
+					hostName = dnsName.substring(0,dnsName.indexOf("."));
+					Logger.getLogger(this.getClass()).info("createInstance() set hostname " + hostName);
+					instance.setHostName(hostName);
+				}
 				instance.setIpAddress(awsInstance.getPrivateIpAddress());
 			}
 
@@ -360,12 +384,34 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 		instance.setPlatform(awsInstance.getPlatform() == null ? PlatformKind.linux: PlatformKind.windows);
 		instance.setState(instanceStateKind(awsInstance.getState().getName()));
 
+		String dnsName;
+		String hostName;
 		if (AWSOptionPropertyConstants.aws_node_ip.match(AWSOptionPropertyConstants.qublic)) {
-			instance.setHostName(awsInstance.getPublicDnsName());
+			dnsName = awsInstance.getPublicDnsName();
+			Logger.getLogger(this.getClass()).info("convertInstance() public dns(fqdn) " + dnsName);
+			if(fqdn || dnsName == null || !dnsName.contains(".")){
+				instance.setHostName(dnsName);
+				Logger.getLogger(this.getClass()).info("convertInstance() set public dns(fqdn) " + dnsName);
+			}
+			else{
+				hostName = dnsName.substring(0,dnsName.indexOf("."));
+				Logger.getLogger(this.getClass()).info("convertInstance() set hostname " + hostName);
+				instance.setHostName(hostName);
+			}
 			instance.setIpAddress(awsInstance.getPublicIpAddress());
 		}
 		else {
-			instance.setHostName(awsInstance.getPrivateDnsName());
+			dnsName = awsInstance.getPrivateDnsName();
+			Logger.getLogger(this.getClass()).info("convertInstance() private dns(fqdn) " + dnsName);
+			if(fqdn || dnsName == null || !dnsName.contains(".")){
+				instance.setHostName(dnsName);
+				Logger.getLogger(this.getClass()).info("convertInstance() set private dns(fqdn) " + dnsName);
+			}
+			else{
+				hostName = dnsName.substring(0,dnsName.indexOf("."));
+				Logger.getLogger(this.getClass()).info("convertInstance() set hostname " + hostName);
+				instance.setHostName(hostName);
+			}
 			instance.setIpAddress(awsInstance.getPrivateIpAddress());
 		}
 
@@ -486,9 +532,18 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 
 	@Override
 	public List<String> getInstanceFlavors() throws CloudManagerFault {
+		String instanceTypeString = AWSOptionPropertyConstants.aws_instance_type.value();
+		
 		List<String> instanceTypes = new ArrayList<>();
-		for (InstanceType type: InstanceType.values()) {
-			instanceTypes.add(type.toString());
+		if(instanceTypeString != null && instanceTypeString.length() > 0){
+			String[] types = instanceTypeString.split(",");
+			for (int i = 0; i < types.length; i++) {
+				instanceTypes.add(types[i]);
+			}
+		}else{
+			for (InstanceType type: InstanceType.values()) {
+				instanceTypes.add(type.toString());
+			}
 		}
 		return instanceTypes;
 	}
